@@ -423,7 +423,7 @@ class H512(ScaleType):
 
 class Struct(ScaleType):
 
-    def __init__(self, data, type_mapping=None, **kwargs):
+    def __init__(self, data=None, type_mapping=None, **kwargs):
 
         if type_mapping:
             self.type_mapping = type_mapping
@@ -921,7 +921,7 @@ class Enum(ScaleType):
     value_list = []
     type_mapping = None
 
-    def __init__(self, data, value_list=None, type_mapping=None, **kwargs):
+    def __init__(self, data=None, value_list=None, type_mapping=None, **kwargs):
 
         self.index = None
 
@@ -1298,6 +1298,21 @@ class GenericCall(ScaleType):
         return data
 
 
+class GenericContractExecResult(Enum):
+    def __init__(self, data=None, data_scale_type=None, **kwargs):
+        self.data_scale_type = data_scale_type
+        super().__init__(data, **kwargs)
+
+    def process_encode(self, value):
+
+        if self.data_scale_type is None:
+            raise ValueError("Encoding is not possible because data_scale_type is not set")
+
+        if 'success' in value:
+            value = {'Success': value['success']}
+        return super().process_encode(value)
+
+
 class OpaqueCall(Bytes):
 
     def process_encode(self, value):
@@ -1411,12 +1426,14 @@ class GenericMultiAddress(Enum):
         value = super().process()
         self.account_length = self.index
         if self.index == 0:
-            self.account_id = list(value.values())[0][2:]
+            value = list(value.values())[0]
+            self.account_id = value[2:]
+            return value
         elif self.index == 1:
             self.account_index = list(value.values())[0]
+            return self.account_index
         else:
             raise NotImplementedError("Address type not yet supported")
-        return value
 
     def process_encode(self, value):
 
